@@ -19,9 +19,6 @@ class ChannelManager(TreeManager):
             return super(ChannelManager, self).get_query_set().filter(
                 site__domain=site, homepage=True, published=True).get()
         except Channel.DoesNotExist:
-            if getattr(settings, 'OPPS_MULTISITE_FALLBACK', None):
-                return super(ChannelManager, self).get_query_set().filter(
-                    homepage=True, published=True)[0]
             return None
 
 
