@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django import template
 from django.conf import settings
+from django.core.cache import cache
 
 from opps.channels.models import Channel
 
@@ -25,5 +26,11 @@ def get_channel(slug):
 @register.assignment_tag
 def get_channels_by(**filters):
     """Return a list of channels filtered by given args"""
-    return Channel.objects.filter(site=settings.SITE_ID, published=True,
-                                  **filters)
+    cache_key = u'getchannelsby-{}'.format(hash(frozenset(filters.items())))
+    if cache.get(cache_key):
+        return cache.get(cache_key)
+
+    channels = Channel.objects.filter(site=settings.SITE_ID, published=True,
+                                      **filters)
+    cache.set(cache_key, channels, 60 * 60)
+    return channels
