@@ -170,7 +170,8 @@ def get_containerbox(context, slug, template_name=None, **extra_context):
     context = {
         'articlebox': box,
         'slug': slug,
-        'context': context
+        'context': context,
+        'request': request
     }
 
     context.update(extra_context)
@@ -414,12 +415,21 @@ def get_container_by_channel(slug, number=10, depth=1,
     box = None
     magic_date = kwargs.pop('magic_date', False)
     date = timezone.now()
+
     if magic_date:
         try:
             date = magicdate(magic_date)
         except Exception:
             pass
 
+    # __in split treatment
+    splited = {
+        key: value.split(',')
+        for key, value
+        in kwargs.items()
+        if key.endswith('__in') and type(value) is not list}
+    kwargs.update(splited)
+
     if include_children:
         try:
             kwargs['channel_long_slug__in'] = cache.get(
@@ -533,3 +543,30 @@ def get_custom_field_value(obj, field_slug):
         return None
 
     return obj.custom_fields().get(field_slug)
+
+
+@register.assignment_tag
+def get_postrelated_by(obj, **filters):
+    """Return a list of post related filtered by given args"""
+    if getattr(obj, 'postrelated_post', False):
+        cachekey = u'getpostrelatedby-{}-{}'.format(hash(frozenset(
+                                                    filters.items())), obj.pk)
+
+        _cache = cache.get(cachekey)
+
+        if _cache:
+            return _cache
+
+        queryset = obj.postrelated_post.filter(post__pk=obj.pk)
+
+        if 'exclude' in filters.keys():
+            del filters['exclude']
+            containers = [i.related for i in queryset.exclude(**filters)
+                                                     .order_by('order')]
+        else:
+            containers = [i.related for i in queryset.filter(**filters)
+                                                     .order_by('order')]
+
+        cache.set(cachekey, containers, 3600)
+        return containers
+    return ''
