@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 from django.utils.translation import ugettext_lazy as _
-from django.conf import settings
 
 from appconf import AppConf
 
@@ -32,6 +31,8 @@ class OppsCoreConf(AppConf):
     SMART_SLUG_ENABLED = True
     MENU = True
     MIRROR_CHANNEL = False
+    CONTAINERS_BLACKLIST = ['Entry']
+    CONTAINERS_SITE_ID = None
 
     # default settings for tinymce
     EDITOR = {
@@ -156,10 +157,3 @@ class ThumborConf(AppConf):
 class DjangoConf(AppConf):
     CACHES = {'default': {
         'BACKEND': 'django.core.cache.backends.dummy.DummyCache'}}
-
-
-settings.INSTALLED_APPS += (
-    'appconf',
-    'haystack',
-    'googl',
-    'mptt',)
